SyndicationTool - Overview: CMF Syndication Reporting Facility
==============================================================

  Description

    The SyndicationTool Reporting Facility is planned to be added to
    the next release of the Syndication services for the CMF.
    I hope to have generated enough feedback from users who might have
    definate ideas which would make a good foundation as a default
    suite of reports.  The plan is not to be all inclusive, but to
    provide a mechanism to generate interesting SiteAdmin data regarding
    the use of Syndication within their sites.
